@@ -1,4 +1,4 @@
-# @(#)Ident: Bob.pm 2013-07-28 22:38 pjf ;
+# @(#)Ident: Bob.pm 2013-08-09 18:44 pjf ;
 
 package Bob;
 
@@ -10,17 +10,13 @@ sub whimper { print {*STDOUT} $_[ 0 ]."\n"; exit 0 }
 
 BEGIN { my $reason; $reason = CPANTesting::should_abort and whimper $reason; }
 
-use version; our $VERSION = qv( '1.14' );
+use version; our $VERSION = qv( '1.22' );
 
 use File::Spec::Functions qw( catfile );
 use Module::Build;
 
 sub new {
-   my ($class, $p) = @_; $p ||= {}; $p->{requires} ||= {};
-
-   my $perl_ver    = $p->{requires}->{perl} || 5.008_008;
-
-   $] < $perl_ver and whimper "Perl minimum ${perl_ver}";
+   my ($class, $p) = @_; $p ||= {}; $p->{requires} ||= {}; __is_above_min( $p );
 
    my $module      = $p->{module} or whimper 'No module name';
    my $distname    = $module; $distname =~ s{ :: }{-}gmx;
@@ -46,6 +42,15 @@ sub new {
 }
 
 # Private functions
+sub __is_above_min {
+   my $p        = shift;
+   my $perl_ver = $p->{_min_perl_ver} = $p->{requires}->{perl} || 5.008;
+
+   $] >= $perl_ver and return;
+   CPANTesting::is_testing() and $ENV{PERL5_CPANPLUS_IS_VERSION} and return;
+   whimper "Minimum required Perl version is ${perl_ver}";
+}
+
 sub __is_src { # Is this the developer authoring a module?
    return -f 'MANIFEST.SKIP';
 }
